@@ -6,9 +6,11 @@ from trdb2py.timeutils import str2timestamp
 from trdb2py.pdutils import buildPNLReport
 from trdb2py.statistics import (calcPNLWinRateInYear, buildPNLWinRateInYears,
                                 buildPNLWinRateInMonths, buildPNLListWinRateInYears2,
-                                buildPNLListWinRateInMonths2, buildPNLListWinRate4Month)
+                                buildPNLListWinRateInMonths2, buildPNLListWinRate4Month,
+                                buildPNLListResponseRateInYears2)
 from trdb2py.plotly import (showAssetCandles, showHeatmap, showHeatmapWinRateInYears,
                             showWinRateInYears, showHeatmapWinRateInMonths, showWinRateInMonths,
-                            showBarWinRateInMonths, showBarWinRateInYears, showBarWinRate4Month, showPNL, showPNLs, showPNLs2)
+                            showBarWinRateInMonths, showBarWinRateInYears, showBarWinRate4Month,
+                            showPNL, showPNLs, showPNLs2, showBarResponseRateInYears)
 from trdb2py.trdb2utils import analysisResult
 import trdb2py.trading2_pb2
